==> haskell-lucid-2.9.10-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.10
id: lucid-2.9.10-35lqhjFJorN8beDGNlMz1a
key: lucid-2.9.10-35lqhjFJorN8beDGNlMz1a
license: BSD3
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
author: Chris Done
exposed: True
indefinite: False
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
abi: 5149e8a67357d452bf80164c00cfa04d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/lucid-2.9.10
library-dirs: /usr/lib/ghc-8.2.2/site-local/lucid-2.9.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/lucid-2.9.10
hs-libraries: HSlucid-2.9.10-35lqhjFJorN8beDGNlMz1a
depends:
    base-4.10.1.0 blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7
    bytestring-0.10.8.2 containers-0.5.10.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    mmorph-1.1.2-KKZMr2x9eQv4KwETGEYeu mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7=3e7866bdfc4c145dc5858d744aeae7aa
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             mmorph-1.1.2-KKZMr2x9eQv4KwETGEYeu=5fa90a74e8da06f2ac014a5b11b06a5b
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.9.10-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.10
id: lucid-2.9.10-3CSpQMNOD6v8noD86zbBMT
key: lucid-2.9.10-3CSpQMNOD6v8noD86zbBMT
license: BSD3
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
author: Chris Done
exposed: True
indefinite: False
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
abi: 5c4d16ed5995ab81ae132acc28ca3df9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/lucid-2.9.10
library-dirs: /usr/lib/ghc-8.2.2/site-local/lucid-2.9.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/lucid-2.9.10
hs-libraries: HSlucid-2.9.10-3CSpQMNOD6v8noD86zbBMT
depends:
    base-4.10.1.0 blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7
    bytestring-0.10.8.2 containers-0.5.10.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    mmorph-1.1.2-KKZMr2x9eQv4KwETGEYeu mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7=3e7866bdfc4c145dc5858d744aeae7aa
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             mmorph-1.1.2-KKZMr2x9eQv4KwETGEYeu=5fa90a74e8da06f2ac014a5b11b06a5b
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
